Time functions
=========================

Output from PCR-GLOBWB (particularly discharge) is often at the daily resolution.

In case statistics or aggregations in time are needed, those functions could be used:

.. automodule:: time_funcs
    :members: